.. Copyright (C) 2017 nickolas360 <contact@nickolas360.com>

.. This file is part of pyrcb2-docs, documentation for pyrcb2.

.. pyrcb2-docs is licensed under the GNU Lesser General Public License
   as published by the Free Software Foundation, either version 3 of
   the License, or (at your option) any later version.

.. As an additional permission under GNU GPL version 3 section 7, you
   may distribute non-source forms of pyrcb2-docs without the copy of
   the GNU GPL normally required by section 4, provided you include a
   URL through which recipients can obtain a copy of the Corresponding
   Source and the GPL at no charge.

.. pyrcb2-docs is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU Lesser General Public License for more details.

.. You should have received a copy of the GNU Lesser General Public License
   along with pyrcb2-docs.  If not, see <http://www.gnu.org/licenses/>.

.. currentmodule:: pyrcb2

Version 0.4
===========

Changelog
---------

.. _changelog-0.4.2:

0.4.2
~~~~~

* Fixed links that were pointing to the old documentation.

.. _changelog-0.4.1:

0.4.1
~~~~~

* Moved documentation to `<https://nickolas360.com/pyrcb2/>`_.

.. _changelog-0.4.0:

0.4.0
~~~~~

* Added :meth:`IRCBot.parse` to the documentation.
* Fixed the documentation for :meth:`IRCBot.kick`.
* Fixed a minor error in the documentation.
* Cleaned up some parts of the code.
